@@ -91,7 +91,7 @@ class CakePlugin {
 		if (is_array($plugin)) {
 			foreach ($plugin as $name => $conf) {
 				list($name, $conf) = (is_numeric($name)) ? array($conf, $config) : array($name, $conf);
-				self::load($name, $conf);
+				static::load($name, $conf);
 			}
 			return;
 		}
@@ -99,26 +99,26 @@ class CakePlugin {
 		if (empty($config['path'])) {
 			foreach (App::path('plugins') as $path) {
 				if (is_dir($path . $plugin)) {
-					self::$_plugins[$plugin] = $config + array('path' => $path . $plugin . DS);
+					static::$_plugins[$plugin] = $config + array('path' => $path . $plugin . DS);
 					break;
 				}
 
 				//Backwards compatibility to make easier to migrate to 2.0
 				$underscored = Inflector::underscore($plugin);
 				if (is_dir($path . $underscored)) {
-					self::$_plugins[$plugin] = $config + array('path' => $path . $underscored . DS);
+					static::$_plugins[$plugin] = $config + array('path' => $path . $underscored . DS);
 					break;
 				}
 			}
 		} else {
-			self::$_plugins[$plugin] = $config;
+			static::$_plugins[$plugin] = $config;
 		}
 
-		if (empty(self::$_plugins[$plugin]['path'])) {
+		if (empty(static::$_plugins[$plugin]['path'])) {
 			throw new MissingPluginException(array('plugin' => $plugin));
 		}
-		if (!empty(self::$_plugins[$plugin]['bootstrap'])) {
-			self::bootstrap($plugin);
+		if (!empty(static::$_plugins[$plugin]['bootstrap'])) {
+			static::bootstrap($plugin);
 		}
 	}
 
@@ -160,7 +160,7 @@ class CakePlugin {
 			if (isset($options[0])) {
 				$opts += $options[0];
 			}
-			self::load($p, $opts);
+			static::load($p, $opts);
 		}
 	}
 
@@ -172,10 +172,10 @@ class CakePlugin {
  * @throws MissingPluginException if the folder for plugin was not found or plugin has not been loaded
  */
 	public static function path($plugin) {
-		if (empty(self::$_plugins[$plugin])) {
+		if (empty(static::$_plugins[$plugin])) {
 			throw new MissingPluginException(array('plugin' => $plugin));
 		}
-		return self::$_plugins[$plugin]['path'];
+		return static::$_plugins[$plugin]['path'];
 	}
 
 /**
@@ -186,7 +186,7 @@ class CakePlugin {
  * @see CakePlugin::load() for examples of bootstrap configuration
  */
 	public static function bootstrap($plugin) {
-		$config = self::$_plugins[$plugin];
+		$config = static::$_plugins[$plugin];
 		if ($config['bootstrap'] === false) {
 			return false;
 		}
@@ -194,9 +194,9 @@ class CakePlugin {
 			return call_user_func_array($config['bootstrap'], array($plugin, $config));
 		}
 
-		$path = self::path($plugin);
+		$path = static::path($plugin);
 		if ($config['bootstrap'] === true) {
-			return self::_includeFile(
+			return static::_includeFile(
 				$path . 'Config' . DS . 'bootstrap.php',
 				$config['ignoreMissing']
 			);
@@ -204,7 +204,7 @@ class CakePlugin {
 
 		$bootstrap = (array)$config['bootstrap'];
 		foreach ($bootstrap as $file) {
-			self::_includeFile(
+			static::_includeFile(
 				$path . 'Config' . DS . $file . '.php',
 				$config['ignoreMissing']
 			);
@@ -222,17 +222,17 @@ class CakePlugin {
  */
 	public static function routes($plugin = null) {
 		if ($plugin === null) {
-			foreach (self::loaded() as $p) {
-				self::routes($p);
+			foreach (static::loaded() as $p) {
+				static::routes($p);
 			}
 			return true;
 		}
-		$config = self::$_plugins[$plugin];
+		$config = static::$_plugins[$plugin];
 		if ($config['routes'] === false) {
 			return false;
 		}
-		return (bool)self::_includeFile(
-			self::path($plugin) . 'Config' . DS . 'routes.php',
+		return (bool)static::_includeFile(
+			static::path($plugin) . 'Config' . DS . 'routes.php',
 			$config['ignoreMissing']
 		);
 	}
@@ -247,9 +247,9 @@ class CakePlugin {
  */
 	public static function loaded($plugin = null) {
 		if ($plugin) {
-			return isset(self::$_plugins[$plugin]);
+			return isset(static::$_plugins[$plugin]);
 		}
-		$return = array_keys(self::$_plugins);
+		$return = array_keys(static::$_plugins);
 		sort($return);
 		return $return;
 	}
@@ -262,9 +262,9 @@ class CakePlugin {
  */
 	public static function unload($plugin = null) {
 		if ($plugin === null) {
-			self::$_plugins = array();
+			static::$_plugins = array();
 		} else {
-			unset(self::$_plugins[$plugin]);
+			unset(static::$_plugins[$plugin]);
 		}
 	}
 
