@@ -44,7 +44,7 @@ class TreeBehavior extends ModelBehavior {
  * @var array
  */
 	protected $_defaults = array(
-		'parent' => 'parent_id', 'left' => 'lft', 'right' => 'rght',
+		'parent' => 'parent_id', 'left' => 'lft', 'right' => 'rght', 'level' => null,
 		'scope' => '1 = 1', 'type' => 'nested', '__parentChange' => false, 'recursive' => -1
 	);
 
@@ -97,10 +97,47 @@ class TreeBehavior extends ModelBehavior {
 			}
 		} elseif ($this->settings[$Model->alias]['__parentChange']) {
 			$this->settings[$Model->alias]['__parentChange'] = false;
+			if ($level) {
+				$this->_setChildrenLevel($Model, $Model->id);
+			}
 			return $this->_setParent($Model, $Model->data[$Model->alias][$parent]);
 		}
 	}
 
+/**
+ * Set level for descendents.
+ *
+ * @param Model $Model Model using this behavior.
+ * @param int|string $id Record ID
+ * @return void
+ */
+	protected function _setChildrenLevel(Model $Model, $id) {
+		$settings = $Model->Behaviors->Tree->settings[$Model->alias];
+		$primaryKey = $Model->primaryKey;
+		$depths = array($id => (int)$Model->data[$Model->alias][$settings['level']]);
+
+		$children = $Model->children(
+			$id,
+			false,
+			array($primaryKey, $settings['parent'], $settings['level']),
+			$settings['left'],
+			null,
+			1,
+			-1
+		);
+
+		foreach ($children as $node) {
+			$parentIdValue = $node[$Model->alias][$settings['parent']];
+			$depth = (int)$depths[$parentIdValue] + 1;
+			$depths[$node[$Model->alias][$primaryKey]] = $depth;
+
+			$Model->updateAll(
+				array($Model->escapeField($settings['level']) => $depth),
+				array($Model->escapeField($primaryKey) => $node[$Model->alias][$primaryKey])
+			);
+		}
+	}
+
 /**
  * Runs before a find() operation
  *
@@ -182,8 +219,13 @@ class TreeBehavior extends ModelBehavior {
 		extract($this->settings[$Model->alias]);
 
 		$this->_addToWhitelist($Model, array($left, $right));
+		if ($level) {
+			$this->_addToWhitelist($Model, $level);
+		}
+		$parentIsSet = array_key_exists($parent, $Model->data[$Model->alias]);
+
 		if (!$Model->id || !$Model->exists()) {
-			if (array_key_exists($parent, $Model->data[$Model->alias]) && $Model->data[$Model->alias][$parent]) {
+			if ($parentIsSet && $Model->data[$Model->alias][$parent]) {
 				$parentNode = $this->_getNode($Model, $Model->data[$Model->alias][$parent]);
 				if (!$parentNode) {
 					return false;
@@ -191,22 +233,31 @@ class TreeBehavior extends ModelBehavior {
 
 				$Model->data[$Model->alias][$left] = 0;
 				$Model->data[$Model->alias][$right] = 0;
+				if ($level) {
+					$Model->data[$Model->alias][$level] = (int)$parentNode[$Model->alias][$level] + 1;
+				}
 				return true;
 			}
 
 			$edge = $this->_getMax($Model, $scope, $right, $recursive);
 			$Model->data[$Model->alias][$left] = $edge + 1;
 			$Model->data[$Model->alias][$right] = $edge + 2;
+			if ($level) {
+				$Model->data[$Model->alias][$level] = 0;
+			}
 			return true;
 		}
 
-		if (array_key_exists($parent, $Model->data[$Model->alias])) {
+		if ($parentIsSet) {
 			if ($Model->data[$Model->alias][$parent] != $Model->field($parent)) {
 				$this->settings[$Model->alias]['__parentChange'] = true;
 			}
 			if (!$Model->data[$Model->alias][$parent]) {
 				$Model->data[$Model->alias][$parent] = null;
 				$this->_addToWhitelist($Model, $parent);
+				if ($level) {
+					$Model->data[$Model->alias][$level] = 0;
+				}
 				return true;
 			}
 
@@ -228,6 +279,9 @@ class TreeBehavior extends ModelBehavior {
 			if ($node[$Model->primaryKey] === $parentNode[$Model->primaryKey]) {
 				return false;
 			}
+			if ($level) {
+				$Model->data[$Model->alias][$level] = (int)$parentNode[$level] + 1;
+			}
 		}
 
 		return true;
@@ -242,10 +296,14 @@ class TreeBehavior extends ModelBehavior {
  */
 	protected function _getNode(Model $Model, $id) {
 		$settings = $this->settings[$Model->alias];
+		$fields = array($Model->primaryKey, $settings['parent'], $settings['left'], $settings['right']);
+		if ($settings['level']) {
+			$fields[] = $settings['level'];
+		}
 
 		return $Model->find('first', array(
 			'conditions' => array($Model->escapeField() => $id),
-			'fields' => array($Model->primaryKey, $settings['parent'], $settings['left'], $settings['right']),
+			'fields' => $fields,
 			'recursive' => $settings['recursive'],
 			'order' => false,
 		));
@@ -384,27 +442,61 @@ class TreeBehavior extends ModelBehavior {
 			$fields = array($Model->primaryKey, $Model->displayField, $left, $right);
 		}
 
-		if (!$keyPath) {
-			$keyPath = '{n}.' . $Model->alias . '.' . $Model->primaryKey;
-		}
-
-		if (!$valuePath) {
-			$valuePath = array('%s%s', '{n}.tree_prefix', '{n}.' . $Model->alias . '.' . $Model->displayField);
-
-		} elseif (is_string($valuePath)) {
-			$valuePath = array('%s%s', '{n}.tree_prefix', $valuePath);
-
-		} else {
-			array_unshift($valuePath, '%s' . $valuePath[0], '{n}.tree_prefix');
-		}
-
 		$conditions = (array)$conditions;
 		if ($scope) {
 			$conditions[] = $scope;
 		}
 
-		$order = $Model->escapeField($left) . " asc";
+		$order = $Model->escapeField($left) . ' asc';
 		$results = $Model->find('all', compact('conditions', 'fields', 'order', 'recursive'));
+
+		return $this->formatTreeList($Model, $results, compact('keyPath', 'valuePath', 'spacer'));
+	}
+
+/**
+ * Formats result of a find() call to a hierarchical array used for HTML select boxes.
+ *
+ * Note that when using your own find() call this expects the order to be "left" field asc in order
+ * to generate the same result as using generateTreeList() directly.
+ *
+ * Options:
+ *
+ * - 'keyPath': A string path to the key, i.e. "{n}.Post.id"
+ * - 'valuePath': A string path to the value, i.e. "{n}.Post.title"
+ * - 'spacer': The character or characters which will be repeated
+ *
+ * @param Model $Model Model using this behavior
+ * @param array $results Result array of a find() call
+ * @param array $options Options
+ * @return array An associative array of records, where the id is the key, and the display field is the value
+ */
+	public function formatTreeList(Model $Model, array $results, array $options = array()) {
+		if (empty($results)) {
+			return array();
+		}
+		$defaults = array(
+			'keyPath' => null,
+			'valuePath' => null,
+			'spacer' => '_'
+		);
+		$options += $defaults;
+
+		extract($this->settings[$Model->alias]);
+
+		if (!$options['keyPath']) {
+			$options['keyPath'] = '{n}.' . $Model->alias . '.' . $Model->primaryKey;
+		}
+
+		if (!$options['valuePath']) {
+			$options['valuePath'] = array('%s%s', '{n}.tree_prefix', '{n}.' . $Model->alias . '.' . $Model->displayField);
+
+		} elseif (is_string($options['valuePath'])) {
+			$options['valuePath'] = array('%s%s', '{n}.tree_prefix', $options['valuePath']);
+
+		} else {
+			array_unshift($options['valuePath'], '%s' . $options['valuePath'][0], '{n}.tree_prefix');
+		}
+
 		$stack = array();
 
 		foreach ($results as $i => $result) {
@@ -413,13 +505,11 @@ class TreeBehavior extends ModelBehavior {
 				array_pop($stack);
 				$count--;
 			}
-			$results[$i]['tree_prefix'] = str_repeat($spacer, $count);
+			$results[$i]['tree_prefix'] = str_repeat($options['spacer'], $count);
 			$stack[] = $result[$Model->alias][$right];
 		}
-		if (empty($results)) {
-			return array();
-		}
-		return Hash::combine($results, $keyPath, $valuePath);
+
+		return Hash::combine($results, $options['keyPath'], $options['valuePath']);
 	}
 
 /**
@@ -970,6 +1060,41 @@ class TreeBehavior extends ModelBehavior {
 		return true;
 	}
 
+/**
+ * Returns the depth level of a node in the tree.
+ *
+ * @param Model $Model Model using this behavior
+ * @param int|string $id The primary key for record to get the level of.
+ * @return int|bool Integer of the level or false if the node does not exist.
+ */
+	public function getLevel(Model $Model, $id = null) {
+		if ($id === null) {
+			$id = $Model->id;
+		}
+
+		$node = $Model->find('first', array(
+			'conditions' => array($Model->escapeField() => $id),
+			'order' => false,
+			'recursive' => -1
+		));
+
+		if (empty($node)) {
+			return false;
+		}
+
+		extract($this->settings[$Model->alias]);
+
+		return $Model->find('count', array(
+			'conditions' => array(
+				$scope,
+				$left . ' <' => $node[$Model->alias][$left],
+				$right . ' >' => $node[$Model->alias][$right]
+			),
+			'order' => false,
+			'recursive' => -1
+		));
+	}
+
 /**
  * Sets the parent of the given node
  *
