@@ -339,7 +339,7 @@ class CakeEmail {
 /**
  * An instance of the EmailConfig class can be set here
  *
- * @var string
+ * @var EmailConfig
  */
 	protected $_configInstance;
 
@@ -360,7 +360,7 @@ class CakeEmail {
 
 		if ($config) {
 			$this->config($config);
-		} elseif (class_exists($this->_configClass) && config('email')) {
+		} elseif (config('email') && class_exists($this->_configClass)) {
 			$this->_configInstance = new $this->_configClass();
 			if (isset($this->_configInstance->default)) {
 				$this->config('default');
@@ -457,7 +457,7 @@ class CakeEmail {
  * @param string|array $email Null to get, String with email,
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
- * @return array|CakeEmail
+ * @return array|self
  */
 	public function to($email = null, $name = null) {
 		if ($email === null) {
@@ -472,7 +472,7 @@ class CakeEmail {
  * @param string|array $email Null to get, String with email,
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
- * @return $this
+ * @return self
  */
 	public function addTo($email, $name = null) {
 		return $this->_addEmail('_to', $email, $name);
@@ -484,7 +484,7 @@ class CakeEmail {
  * @param string|array $email Null to get, String with email,
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
- * @return array|CakeEmail
+ * @return array|self
  */
 	public function cc($email = null, $name = null) {
 		if ($email === null) {
@@ -499,7 +499,7 @@ class CakeEmail {
  * @param string|array $email Null to get, String with email,
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
- * @return $this
+ * @return self
  */
 	public function addCc($email, $name = null) {
 		return $this->_addEmail('_cc', $email, $name);
@@ -511,7 +511,7 @@ class CakeEmail {
  * @param string|array $email Null to get, String with email,
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
- * @return array|CakeEmail
+ * @return array|self
  */
 	public function bcc($email = null, $name = null) {
 		if ($email === null) {
@@ -526,7 +526,7 @@ class CakeEmail {
  * @param string|array $email Null to get, String with email,
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
- * @return $this
+ * @return self
  */
 	public function addBcc($email, $name = null) {
 		return $this->_addEmail('_bcc', $email, $name);
@@ -568,7 +568,7 @@ class CakeEmail {
  * @param string|bool|null $regex The pattern to use for email address validation,
  *   null to unset the pattern and make use of filter_var() instead, false or
  *   nothing to return the current value
- * @return string|$this
+ * @return string|self
  */
 	public function emailPattern($regex = false) {
 		if ($regex === false) {
@@ -585,7 +585,7 @@ class CakeEmail {
  * @param string|array $email String with email,
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
- * @return $this
+ * @return self
  */
 	protected function _setEmail($varName, $email, $name) {
 		if (!is_array($email)) {
@@ -634,7 +634,7 @@ class CakeEmail {
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
  * @param string $throwMessage Exception message
- * @return $this
+ * @return self
  * @throws SocketException
  */
 	protected function _setEmailSingle($varName, $email, $name, $throwMessage) {
@@ -654,7 +654,7 @@ class CakeEmail {
  * @param string|array $email String with email,
  *   Array with email as key, name as value or email as value (without name)
  * @param string $name Name
- * @return $this
+ * @return self
  * @throws SocketException
  */
 	protected function _addEmail($varName, $email, $name) {
@@ -682,7 +682,7 @@ class CakeEmail {
  * Get/Set Subject.
  *
  * @param string $subject Subject string.
- * @return string|$this
+ * @return string|self
  */
 	public function subject($subject = null) {
 		if ($subject === null) {
@@ -696,7 +696,7 @@ class CakeEmail {
  * Sets headers for the message
  *
  * @param array $headers Associative array containing headers to be set.
- * @return $this
+ * @return self
  * @throws SocketException
  */
 	public function setHeaders($headers) {
@@ -711,7 +711,7 @@ class CakeEmail {
  * Add header for the message
  *
  * @param array $headers Headers to set.
- * @return $this
+ * @return self
  * @throws SocketException
  */
 	public function addHeaders($headers) {
@@ -844,7 +844,7 @@ class CakeEmail {
  *
  * @param bool|string $template Template name or null to not use
  * @param bool|string $layout Layout name or null to not use
- * @return array|$this
+ * @return array|self
  */
 	public function template($template = false, $layout = false) {
 		if ($template === false) {
@@ -864,7 +864,7 @@ class CakeEmail {
  * View class for render
  *
  * @param string $viewClass View class name.
- * @return string|$this
+ * @return string|self
  */
 	public function viewRender($viewClass = null) {
 		if ($viewClass === null) {
@@ -878,7 +878,7 @@ class CakeEmail {
  * Variables to be set on render
  *
  * @param array $viewVars Variables to set for view.
- * @return array|$this
+ * @return array|self
  */
 	public function viewVars($viewVars = null) {
 		if ($viewVars === null) {
@@ -892,7 +892,7 @@ class CakeEmail {
  * Theme to use when rendering
  *
  * @param string $theme Theme name.
- * @return string|$this
+ * @return string|self
  */
 	public function theme($theme = null) {
 		if ($theme === null) {
@@ -906,7 +906,7 @@ class CakeEmail {
  * Helpers to be used in render
  *
  * @param array $helpers Helpers list.
- * @return array|$this
+ * @return array|self
  */
 	public function helpers($helpers = null) {
 		if ($helpers === null) {
@@ -920,7 +920,7 @@ class CakeEmail {
  * Email format
  *
  * @param string $format Formatting string.
- * @return string|$this
+ * @return string|self
  * @throws SocketException
  */
 	public function emailFormat($format = null) {
@@ -938,7 +938,7 @@ class CakeEmail {
  * Transport name
  *
  * @param string $name Transport name.
- * @return string|$this
+ * @return string|self
  */
 	public function transport($name = null) {
 		if ($name === null) {
@@ -975,7 +975,7 @@ class CakeEmail {
  * Message-ID
  *
  * @param bool|string $message True to generate a new Message-ID, False to ignore (not send in email), String to set as Message-ID
- * @return bool|string|$this
+ * @return bool|string|self
  * @throws SocketException
  */
 	public function messageId($message = null) {
@@ -997,7 +997,7 @@ class CakeEmail {
  * Domain as top level (the part after @)
  *
  * @param string $domain Manually set the domain for CLI mailing
- * @return string|$this
+ * @return string|self
  */
 	public function domain($domain = null) {
 		if ($domain === null) {
@@ -1051,7 +1051,7 @@ class CakeEmail {
  * attachment compatibility with outlook email clients.
  *
  * @param string|array $attachments String with the filename or array with filenames
- * @return array|$this Either the array of attachments when getting or $this when setting.
+ * @return array|self Either the array of attachments when getting or $this when setting.
  * @throws SocketException
  */
 	public function attachments($attachments = null) {
@@ -1094,7 +1094,7 @@ class CakeEmail {
  * Add attachments
  *
  * @param string|array $attachments String with the filename or array with filenames
- * @return $this
+ * @return self
  * @throws SocketException
  * @see CakeEmail::attachments()
  */
@@ -1135,7 +1135,7 @@ class CakeEmail {
  * `$email->config(array('to' => 'bill@example.com'));`
  *
  * @param string|array $config String with configuration name (from email.php), array with config or null to return current config
- * @return string|array|$this
+ * @return string|array|self
  */
 	public function config($config = null) {
 		if ($config === null) {
@@ -1199,11 +1199,12 @@ class CakeEmail {
  * @param string|array $message String with message or array with variables to be used in render
  * @param string|array $transportConfig String to use config from EmailConfig or array with configs
  * @param bool $send Send the email or just return the instance pre-configured
- * @return CakeEmail Instance of CakeEmail
+ * @return self Instance of CakeEmail
  * @throws SocketException
  */
 	public static function deliver($to = null, $subject = null, $message = null, $transportConfig = 'fast', $send = true) {
 		$class = __CLASS__;
+		/** @var CakeEmail $instance */
 		$instance = new $class($transportConfig);
 		if ($to !== null) {
 			$instance->to($to);
@@ -1285,7 +1286,7 @@ class CakeEmail {
 /**
  * Reset all CakeEmail internal variables to be able to send out a new email.
  *
- * @return $this
+ * @return self
  */
 	public function reset() {
 		$this->_to = array();
@@ -1673,6 +1674,7 @@ class CakeEmail {
 			App::uses($viewClass, $plugin . 'View');
 		}
 
+		/** @var View $View */
 		$View = new $viewClass(null);
 		$View->viewVars = $this->_viewVars;
 		$View->helpers = $this->_helpers;
