@@ -46,7 +46,8 @@ class TreeBehaviorNumberTest extends CakeTestCase {
 		'modelClass' => 'NumberTree',
 		'leftField' => 'lft',
 		'rightField' => 'rght',
-		'parentField' => 'parent_id'
+		'parentField' => 'parent_id',
+		'level' => 'level'
 	);
 
 /**
@@ -548,6 +549,26 @@ class TreeBehaviorNumberTest extends CakeTestCase {
 		$this->assertTrue($validTree);
 	}
 
+/**
+ * testGetLevel method
+ *
+ * @return void
+ */
+	public function testGetLevel() {
+		extract($this->settings);
+		$this->Tree = new $modelClass();
+		$this->Tree->initialize(2, 2);
+		$this->Tree->id = null;
+
+		$result = $this->Tree->getLevel(5);
+		$this->assertEquals(1, $result);
+
+		$result = $this->Tree->getLevel(3);
+		$this->assertEquals(2, $result);
+
+		$this->assertFalse($this->Tree->getLevel(999));
+	}
+
 /**
  * testMoveWithWhitelist method
  *
@@ -1412,6 +1433,29 @@ class TreeBehaviorNumberTest extends CakeTestCase {
 		$this->assertEquals('__3 - 1.1.1', $result[3]);
 	}
 
+/**
+ * Test the formatting options of formatTreeList()
+ *
+ * @return void
+ */
+	public function testFormatTreeList() {
+		extract($this->settings);
+		$this->Tree = new $modelClass();
+		$this->Tree->initialize(2, 2);
+
+		$options = array('order' => array('lft' => 'asc'));
+		$records = $this->Tree->find('all', $options);
+
+		$options = array(
+			'keyPath' => "{n}.$modelClass.id",
+			'valuePath' => array('%s - %s', "{n}.$modelClass.id", "{n}.$modelClass.name"),
+			'spacer' => '--');
+		$result = $this->Tree->formatTreeList($records, $options);
+		$this->assertEquals('1 - 1. Root', $result[1]);
+		$this->assertEquals('--2 - 1.1', $result[2]);
+		$this->assertEquals('----3 - 1.1.1', $result[3]);
+	}
+
 /**
  * testArraySyntax method
  *
@@ -1507,4 +1551,61 @@ class TreeBehaviorNumberTest extends CakeTestCase {
 		);
 		$this->assertEquals($expected, $result);
 	}
+
+	public function testLevel() {
+		extract($this->settings);
+		$this->Tree = new $modelClass();
+		$this->Tree->Behaviors->attach('Tree', array('level' => 'level'));
+		$this->Tree->initialize(2, 2);
+
+		$result = $this->Tree->findByName('1. Root');
+		$this->assertEquals(0, $result[$modelClass][$level]);
+
+		$result = $this->Tree->findByName('1.1');
+		$this->assertEquals(1, $result[$modelClass][$level]);
+
+		$result = $this->Tree->findByName('1.2.2');
+		$this->assertEquals(2, $result[$modelClass][$level]);
+
+		$result = $this->Tree->findByName('1.2.1');
+		$this->assertEquals(2, $result[$modelClass][$level]);
+
+		// Save with parent_id not set
+		$this->Tree->save(array('id' => $result[$modelClass]['id'], 'name' => 'foo'));
+		$result = $this->Tree->findByName('foo');
+		$this->assertEquals(2, $result[$modelClass][$level]);
+
+		// Save with parent_id not changed
+		$this->Tree->save(array(
+			'id' => $result[$modelClass]['id'],
+			'parent_id' => $result[$modelClass]['parent_id'],
+			'name' => 'foo2'
+		));
+		$result = $this->Tree->findByName('foo2');
+		$this->assertEquals(2, $result[$modelClass][$level]);
+
+		// Save with parent_id changed
+		$result = $this->Tree->findByName('1.1');
+		$this->Tree->save(array(
+			'id' => $result[$modelClass]['id'],
+			'parent_id' => ''
+		));
+		$result = $this->Tree->findByName('1.1');
+		$this->assertEquals(0, $result[$modelClass][$level]);
+
+		$result = $this->Tree->findByName('1.1.2');
+		$this->assertEquals(1, $result[$modelClass][$level]);
+
+		$parent = $this->Tree->findByName('1.1.2');
+		$result = $this->Tree->findByName('1.2');
+		$this->Tree->save(array(
+			'id' => $result[$modelClass]['id'],
+			'parent_id' => $parent[$modelClass]['id']
+		));
+		$result = $this->Tree->findByName('1.2');
+		$this->assertEquals(2, $result[$modelClass][$level]);
+
+		$result = $this->Tree->findByName('1.2.2');
+		$this->assertEquals(3, $result[$modelClass][$level]);
+	}
 }
