@@ -276,7 +276,7 @@ class ControllerTestCaseTest extends CakeTestCase {
  * @return void
  */
 	public function testTestAction() {
-		$Controller = $this->Case->generate('TestsApps');
+		$this->Case->generate('TestsApps');
 		$this->Case->testAction('/tests_apps/index');
 		$this->assertInternalType('array', $this->Case->controller->viewVars);
 
@@ -306,7 +306,7 @@ class ControllerTestCaseTest extends CakeTestCase {
  * @return void
  */
 	public function testTestActionArrayUrls() {
-		$Controller = $this->Case->generate('TestsApps');
+		$this->Case->generate('TestsApps');
 		$this->Case->testAction(array('controller' => 'tests_apps', 'action' => 'index'));
 		$this->assertInternalType('array', $this->Case->controller->viewVars);
 	}
@@ -452,7 +452,7 @@ class ControllerTestCaseTest extends CakeTestCase {
 	public function testTestActionGetData() {
 		$this->Case->autoMock = true;
 
-		$result = $this->Case->testAction('/tests_apps_posts/url_var', array(
+		$this->Case->testAction('/tests_apps_posts/url_var', array(
 			'method' => 'get',
 			'data' => array(
 				'some' => 'var',
@@ -474,7 +474,7 @@ class ControllerTestCaseTest extends CakeTestCase {
 		));
 		$this->assertEquals(array('gogo', 'val2'), $result['params']['pass']);
 
-		$result = $this->Case->testAction('/tests_apps_posts/url_var', array(
+		$this->Case->testAction('/tests_apps_posts/url_var', array(
 			'return' => 'vars',
 			'method' => 'get',
 			'data' => array(
