@@ -1925,6 +1925,21 @@ class HtmlHelperTest extends CakeTestCase {
 		$result = $this->Html->tableCells($tr, array('class' => 'odd'), array('class' => 'even'), false, false);
 		$expected = "<tr class=\"odd\"><td>td content 1</td> <td>td content 2</td> <td>td content 3</td></tr>\n<tr class=\"even\"><td>td content 1</td> <td>td content 2</td> <td>td content 3</td></tr>\n<tr class=\"odd\"><td>td content 1</td> <td>td content 2</td> <td>td content 3</td></tr>";
 		$this->assertEquals($expected, $result);
+
+		$tr = array(
+			'td content 1',
+			'td content 2',
+			array('td content 3', array('class' => 'foo'))
+		);
+		$result = $this->Html->tableCells($tr, null, null, true);
+		$expected = array(
+			'<tr',
+			array('td' => array('class' => 'column-1')), 'td content 1', '/td',
+			array('td' => array('class' => 'column-2')), 'td content 2', '/td',
+			array('td' => array('class' => 'foo column-3')), 'td content 3', '/td',
+			'/tr'
+		);
+		$this->assertTags($result, $expected);
 	}
 
 /**
