@@ -47,7 +47,7 @@ class Inflector {
 			'/(?<!u)(m)an$/i' => '\1en',
 			'/(c)hild$/i' => '\1hildren',
 			'/(buffal|tomat)o$/i' => '\1\2oes',
-			'/(alumn|bacill|cact|foc|fung|nucle|radi|stimul|syllab|termin|vir)us$/i' => '\1i',
+			'/(alumn|bacill|cact|foc|fung|nucle|radi|stimul|syllab|termin)us$/i' => '\1i',
 			'/us$/i' => 'uses',
 			'/(alias)$/i' => '\1es',
 			'/(ax|cris|test)is$/i' => '\1es',
