@@ -228,7 +228,7 @@ class Set {
  * @param array $data Source array from which to extract the data
  * @param string $format Format string into which values will be inserted, see sprintf()
  * @param array $keys An array containing one or more Set::extract()-style key paths
- * @return array An array of strings extracted from $keys and formatted with $format
+ * @return array|null An array of strings extracted from $keys and formatted with $format, otherwise null.
  * @link http://book.cakephp.org/2.0/en/core-utility-libraries/set.html#Set::format
  */
 	public static function format($data, $format, $keys) {
@@ -236,7 +236,7 @@ class Set {
 		$count = count($keys);
 
 		if (!$count) {
-			return;
+			return null;
 		}
 
 		for ($i = 0; $i < $count; $i++) {
