@@ -464,7 +464,7 @@ class View extends Object {
  */
 	public function render($view = null, $layout = null) {
 		if ($this->hasRendered) {
-			return;
+			return null;
 		}
 
 		if ($view !== false && $viewFileName = $this->_getViewFileName($view)) {
@@ -1012,9 +1012,6 @@ class View extends Object {
 			$name = $this->viewPath . DS . $subDir . Inflector::underscore($name);
 		} elseif (strpos($name, DS) !== false) {
 			if ($name[0] === DS || $name[1] === ':') {
-				if (is_file($name)) {
-					return $name;
-				}
 				$name = trim($name, DS);
 			} elseif ($name[0] === '.') {
 				$name = substr($name, 3);
